@@ -21,7 +21,6 @@ import org.gwtopenmaps.openlayers.client.control.DrawFeature;
 import org.gwtopenmaps.openlayers.client.control.DrawFeature.FeatureAddedListener;
 import org.gwtopenmaps.openlayers.client.control.DrawFeatureOptions;
 import org.gwtopenmaps.openlayers.client.control.LayerSwitcher;
-import org.gwtopenmaps.openlayers.client.control.MouseDefaults;
 import org.gwtopenmaps.openlayers.client.control.MousePosition;
 import org.gwtopenmaps.openlayers.client.control.MousePositionOptions;
 import org.gwtopenmaps.openlayers.client.control.MousePositionOutput;
@@ -47,7 +46,6 @@ import org.gwtopenmaps.openlayers.client.util.JSObject;
 import com.extjs.gxt.ui.client.widget.ContentPanel;
 import com.extjs.gxt.ui.client.widget.layout.FitLayout;
 import com.google.gwt.core.shared.GWT;
-import com.google.gwt.user.client.Element;
 import com.google.gwt.user.client.Window;
 import com.google.gwt.user.client.ui.DockPanel;
 import com.google.gwt.user.client.ui.Widget;
@@ -144,7 +142,7 @@ public class OpenLayersMap {
 		map = mapWidget.getMap(); // map js-mapped object		
 		mapWidget.setTitle(title); // set title
 		map.setMaxExtent(Constants.defaultBounds);
-		map.setMinMaxZoomLevel(Constants.defaultOpenLayersMapDefaultZoom, numZoomLevels);
+//		map.setMinMaxZoomLevel(Constants.defaultOpenLayersMapDefaultZoom, numZoomLevels);
 		
 		// set click listener on the map
 		map.addMapClickListener(new MapClickListener() {
@@ -467,7 +465,11 @@ public class OpenLayersMap {
 	}
 
 	public void zoomToMaxExtent() {
-		this.map.zoomToMaxExtent();
+		//TO FIX BUG ON MAX EXTENT OPENLAYES 2.13.1
+		this.map.zoomTo(Constants.defaultOpenLayersMapDefaultZoom);
+		this.map.setCenter(new LonLat(0, 0));
+		
+//		this.map.zoomToMaxExtent();
 	}
 	
 	/*
